@@ -2,11 +2,14 @@ use warnings;
 use strict;
 use CGI::Application::Server;
 use lib 'lib';
-use Foo;
+use Foo::Bar;
 
-my $app = Foo->new(PARAMS => {
+my $app = Foo::Bar->new(
+    TMPL_PATH => './share/templates',
+    PARAMS    => {
 
-});
+    },
+);
 
 my $server = CGI::Application::Server->new();
 $server->document_root('./t/www');
